@@ -14,7 +14,7 @@ MUST_INCLUDE_ID_TERM_TYPES = [
 def validate_must_include_id(inputs: list):
     def missingRequiredIds(term: dict):
         term_id = term.get('@id')
-        lookup = download_lookup(f"{term.get('termType')}.csv", True)
+        lookup = download_lookup(f"{term.get('termType')}.csv")
         other_term_ids = (get_table_value(lookup, 'termid', term_id, MUST_INCLUDE_ID_COL) or '').split(',')
         return non_empty_list([
             term_id for term_id in other_term_ids if find_term_match(inputs, term_id, None) is None
