@@ -95,7 +95,7 @@ def _validate_soiltTexture_sum(values: list):
 
 
 def validate_soilTexture(measurements: list):
-    soilTexture = download_lookup('soilTexture.csv', True)
+    soilTexture = download_lookup('soilTexture.csv')
     groupped_values = _group_measurements_depth(enumerate(measurements)).values()
     return _filter_list_errors(
         list(map(_validate_soiltTexture_sum, groupped_values)) +
@@ -115,8 +115,26 @@ def validate_depths(measurements: list):
     return _filter_list_errors(map(validate, enumerate(measurements)))
 
 
+def validate_required_depths(site: dict, list_key: str):
+    def validate(values: tuple):
+        index, measurement = values
+        term = measurement.get('term', {})
+        term_id = term.get('@id')
+        term_type = term.get('termType')
+        lookup = download_lookup(f"{term_type}.csv")
+        with_depth = get_table_value(lookup, 'termid', term_id, column_name('recommendAddingDepth'))
+        has_depths = measurement.get('depthUpper') is not None and measurement.get('depthLower') is not None
+        return not with_depth or with_depth == '' or has_depths or {
+            'level': 'warning',
+            'dataPath': f".{list_key}[{index}]",
+            'message': 'should set both depthUpper and depthLower'
+        }
+
+    return _filter_list_errors(map(validate, enumerate(site.get(list_key, []))))
+
+
 def validate_value_min_max(measurements: list):
-    lookup = download_lookup('measurement.csv', True)
+    lookup = download_lookup('measurement.csv')
 
     def validate(values: tuple):
         index, measurement = values
@@ -139,7 +157,7 @@ def validate_value_min_max(measurements: list):
 
 
 def validate_term_unique(measurements: list):
-    lookup = download_lookup('measurement.csv', True)
+    lookup = download_lookup('measurement.csv')
 
     def count_same_term(term_id: str):
         return len(list(filter(lambda x: x.get('term', {}).get('@id') == term_id, measurements)))
@@ -159,7 +177,7 @@ def validate_term_unique(measurements: list):
 
 
 def validate_require_startDate_endDate(measurements: list):
-    lookup = download_lookup('measurement.csv', True)
+    lookup = download_lookup('measurement.csv')
 
     def validate(values: tuple):
         index, measurement = values
@@ -211,7 +229,7 @@ def validate_value_length(site: dict, list_key: str):
     def validate(values: tuple):
         index, blank_node = values
         term_id = blank_node.get('term', {}).get('@id')
-        lookup = download_lookup('measurement.csv', True)
+        lookup = download_lookup('measurement.csv')
         array_type = get_table_value(lookup, 'termid', term_id, column_name('arrayTreatment'))
         value_length = len(blank_node.get('value', []))
         return array_type != 'arrayNotAllowed' or value_length <= 1 or {
