@@ -3,10 +3,7 @@ from typing import List
 from concurrent.futures import ThreadPoolExecutor
 from functools import reduce
 import re
-from hestia_earth.utils.tools import flatten, non_empty_list, safe_parse_float, list_sum
-from hestia_earth.utils.lookup import download_lookup, get_table_value, column_name
-from hestia_earth.utils.api import download_hestia
-from hestia_earth.utils.model import find_term_match
+from hestia_earth.utils.tools import flatten, list_sum
 
 from hestia_earth.validation.geojson import get_geojson_area
 from hestia_earth.validation.gee import is_enabled, id_to_level, get_region_id
@@ -178,11 +175,10 @@ def validate_list_term_percent(node: dict, list_key: str):
     }
 
     def validate(values: tuple):
-        index, value = values
-        units = value.get('term', {}).get('units', '')
-        value = _value_average(value, None)
-        return units != '%' or value is None or type(value) == str or \
-            soft_validate(index, value) or hard_validate(index, value)
+        index, blank_node = values
+        units = blank_node.get('term', {}).get('units', '')
+        value = _value_average(blank_node, None) if units == '%' else None
+        return value is None or type(value) == str or soft_validate(index, value) or hard_validate(index, value)
 
     return _filter_list_errors(map(validate, enumerate(node.get(list_key, []))))
 
@@ -299,23 +295,6 @@ def validate_linked_source_privacy(node: dict, key: str, node_map: dict):
     }
 
 
-def _property_default_value(term_id: str, property_term_id: str):
-    # load the term defaultProperties and find the matching property
-    term = download_hestia(term_id)
-    return safe_parse_float(find_term_match(term.get('defaultProperties', []), property_term_id).get('value'))
-
-
-def _property_default_allowed_values(term_id: str):
-    lookup = download_lookup('property.csv', True)
-    allowed = get_table_value(lookup, 'termid', term_id, column_name('validationAllowedExceptions'))
-    try:
-        allowed_values = non_empty_list(allowed.split(';')) if allowed else []
-        return [safe_parse_float(v) for v in allowed_values]
-    # failure to split by `;` as single value allowed
-    except AttributeError:
-        return [safe_parse_float(allowed)]
-
-
 def value_difference(value: float, expected_value: float):
     """
     Get the difference in percentage between a value and the expected value.
@@ -358,36 +337,6 @@ def is_value_different(value: float, expected_value: float, delta: float = 0.05)
     return value_difference(value, expected_value) > delta
 
 
-def validate_properties_default_value(node: dict, list_key: str, properties_key: str):
-    def validate_properties(term_id: str, values: tuple):
-        index, prop = values
-        value = safe_parse_float(prop.get('value'))
-        prop_term_id = prop.get('term', {}).get('@id')
-        default_value = _property_default_value(term_id, prop_term_id)
-        delta = value_difference(value, default_value)
-        values_allowed = _property_default_allowed_values(prop_term_id) if prop_term_id else []
-        return delta < 0.25 or value in values_allowed or {
-            'level': 'warning',
-            'dataPath': f".{properties_key}[{index}].value",
-            'message': 'should be within percentage of default value',
-            'params': {
-                'current': value,
-                'default': default_value,
-                'percentage': delta * 100
-            }
-        }
-
-    def validate_nodes(values: tuple):
-        index, value = values
-        term_id = value.get('term', {}).get('@id')
-        errors = _filter_list_errors(
-            flatten(map(lambda v: validate_properties(term_id, v), enumerate(value.get(properties_key, [])))), False
-        )
-        return [update_error_path(error, list_key, index) for error in errors]
-
-    return _filter_list_errors(flatten(map(validate_nodes, enumerate(node.get(list_key, [])))))
-
-
 def _model_value_from_list(results: list, default_value: float):
     return results[0].get('value', [default_value]) if len(results) > 0 else default_value
 
@@ -405,15 +354,26 @@ def _value_from_model(result):
     return list_sum(value, value)
 
 
-def _validate_list_model(node: dict, list_key: str):
+def _parse_node_value(node: dict):
+    def parse_list_value(value: list):
+        return list_sum(value) if len(value) > 0 else None
+
+    value = node.get('value')
+    return None if value is None else (
+        parse_list_value(value) if isinstance(value, list) else value
+    )
+
+
+def _validate_list_model(node: dict, list_key: str, max_delta: float = 0.05):
     def validate(values: tuple):
         index, blank_node = values
         try:
-            value = blank_node.get('value', [0])
-            value = list_sum(value, value)
-            expected_value = _value_from_model(run_model_from_node(blank_node, node))
+            value = _parse_node_value(blank_node)
+            # skip validation if `value` is not set
+            result = run_model_from_node(blank_node, node) if value is not None else None
+            expected_value = _value_from_model(result) if result else 0
             delta = value_difference(value, expected_value)
-            return delta < 0.05 or {
+            return delta < max_delta or {
                 'level': 'error',
                 'dataPath': f".{list_key}[{index}].value",
                 'message': 'the value provided is not consistent with the model result',
@@ -482,14 +442,13 @@ def _validate_list_model_config(node: dict, list_key: str, conf: dict):
 
     def validate(values: tuple):
         index, blank_node = values
-        value = blank_node.get('value', [0])
-        value = list_sum(value, value)
+        value = _parse_node_value(blank_node)
         term = blank_node.get('term', {})
         term_id = blank_node.get('term', {}).get('@id')
         # get the configuration for this element
-        # if it does not exist, skip model
+        # if it does not exist or no `value` is set, skip model
         term_conf = conf.get(term_id)
-        return validate_model(term, value, index, term_conf) if term_conf else True
+        return validate_model(term, value, index, term_conf) if term_conf and value is not None else True
 
     return validate
 
