@@ -10,7 +10,7 @@ from .shared import (
 )
 from .infrastructure import validate_lifespan
 from .measurement import (
-    validate_soilTexture, validate_depths, validate_value_min_max, validate_term_unique,
+    validate_soilTexture, validate_depths, validate_required_depths, validate_value_min_max, validate_term_unique,
     validate_require_startDate_endDate, validate_with_models, validate_value_length
 )
 from .practice import validate_cropResidueManagement, validate_longFallowPeriod
@@ -25,7 +25,8 @@ INLAND_TYPES = [
     SiteSiteType.RIVER_OR_STREAM.value,
     SiteSiteType.LAKE.value,
     SiteSiteType.ANIMAL_HOUSING.value,
-    SiteSiteType.FACTORY.value,
+    SiteSiteType.AGRI_FOOD_PROCESSOR.value,
+    SiteSiteType.FOOD_RETAILER.value,
     SiteSiteType.FOREST.value,
     SiteSiteType.OTHER_NATURAL_VEGETATION.value
 ]
@@ -108,6 +109,7 @@ def validate_site(site: dict, node_map: dict = {}):
         validate_list_term_percent(site, 'measurements'),
         validate_soilTexture(site.get('measurements')),
         validate_depths(site.get('measurements')),
+        validate_required_depths(site, 'measurements'),
         validate_value_min_max(site.get('measurements')),
         validate_term_unique(site.get('measurements')),
         validate_properties_default_value(site, 'measurements'),
