@@ -4,7 +4,7 @@ import json
 from tests.utils import fixtures_path
 from hestia_earth.validation.validators.measurement import (
     validate_soilTexture, validate_depths, validate_value_min_max, validate_term_unique,
-    validate_require_startDate_endDate, validate_with_models, validate_value_length
+    validate_require_startDate_endDate, validate_with_models, validate_value_length, validate_required_depths
 )
 
 class_path = 'hestia_earth.validation.validators.measurement'
@@ -282,3 +282,29 @@ def test_validate_value_length_invalid():
         'dataPath': '.measurements[1].value',
         'message': 'must not contain more than 1 value'
     }
+
+
+def test_validate_required_depths_valid():
+    # no measurements should be valid
+    assert validate_required_depths({}, 'measurements') is True
+
+    with open(f"{fixtures_path}/measurement/required-depths/valid.json") as f:
+        data = json.load(f)
+    assert validate_required_depths(data, 'measurements') is True
+
+
+def test_validate_required_depths_warning():
+    with open(f"{fixtures_path}/measurement/required-depths/warning.json") as f:
+        data = json.load(f)
+    assert validate_required_depths(data, 'measurements') == [
+        {
+            'level': 'warning',
+            'dataPath': '.measurements[3]',
+            'message': 'should set both depthUpper and depthLower'
+        },
+        {
+            'level': 'warning',
+            'dataPath': '.measurements[7]',
+            'message': 'should set both depthUpper and depthLower'
+        }
+    ]
