@@ -6,7 +6,7 @@ from hestia_earth.validation.validators.shared import (
     validate_dates, validate_list_dates, validate_list_duplicates, validate_list_min_max,
     validate_country, validate_region_in_country, validate_is_region, validate_area, validate_coordinates,
     need_validate_coordinates, validate_list_term_percent, validate_empty_fields, validate_linked_source_privacy,
-    validate_list_dates_length, validate_date_lt_today, validate_list_date_lt_today, validate_properties_default_value,
+    validate_list_dates_length, validate_date_lt_today, validate_list_date_lt_today,
     value_difference, is_value_different, validate_list_model, validate_list_model_config,
     validate_properties_same_length, validate_list_duplicate_values, validate_nodes_duplicates
 )
@@ -488,31 +488,6 @@ def test_validate_list_date_lt_today_invalid():
     }
 
 
-def test_validate_properties_default_value_valid():
-    with open(f"{fixtures_path}/shared/properties-default-value/valid.json") as f:
-        node = json.load(f)
-    assert validate_properties_default_value(node, 'inputs', 'properties') is True
-
-    with open(f"{fixtures_path}/shared/properties-default-value/valid-allowed-exception.json") as f:
-        node = json.load(f)
-    assert validate_properties_default_value(node, 'inputs', 'properties') is True
-
-
-def test_validate_properties_default_value_warning():
-    with open(f"{fixtures_path}/shared/properties-default-value/warning.json") as f:
-        node = json.load(f)
-    assert validate_properties_default_value(node, 'inputs', 'properties') == {
-        'level': 'warning',
-        'dataPath': '.inputs[0].properties[0].value',
-        'message': 'should be within percentage of default value',
-        'params': {
-            'current': 67.0,
-            'default': 52.87673036,
-            'percentage': 26.71
-        }
-    }
-
-
 def test_value_difference():
     assert value_difference(125, 100) == 0.25
     assert value_difference(75, 100) == 0.25
@@ -604,6 +579,11 @@ def test_validate_list_model_config_valid():
         data = json.load(f)
     assert validate_list_model_config(data, 'products', PRODUCTS_MODEL_CONFIG) is True
 
+    # missing value should skip validation
+    with open(f"{fixtures_path}/shared/model/products/valid-no-value.json") as f:
+        data = json.load(f)
+    assert validate_list_model_config(data, 'products', PRODUCTS_MODEL_CONFIG) is True
+
 
 def test_validate_list_model_config_invalid():
     # validating Cycle.products
@@ -631,31 +611,6 @@ def test_validate_list_model_config_invalid():
         }
     }
 
-    # missing value should also report warning
-    with open(f"{fixtures_path}/shared/model/products/warning-no-value.json") as f:
-        data = json.load(f)
-    assert validate_list_model_config(data, 'products', PRODUCTS_MODEL_CONFIG) == {
-        'level': 'warning',
-        'dataPath': '.products[1].value',
-        'message': 'the value provided is not consistent with the model result',
-        'params': {
-            'model': {
-                '@type': 'Term',
-                '@id': 'ipcc2006',
-                'name': 'IPCC (2006)',
-                'termType': 'model'
-            },
-            'term': {
-                '@type': 'Term',
-                'name': 'Above Ground Crop Residue Total',
-                '@id': 'aboveGroundCropResidueTotal'
-            },
-            'current': 0,
-            'expected': 3451.52155,
-            'delta': 100
-        }
-    }
-
 
 def test_validate_properties_same_length_valid():
     with open(f"{fixtures_path}/shared/properties-same-length/valid.json") as f:
